	SUBROUTINE CHEPRM (IBUF,ITABLE,IBFOM,RFAC)
C	PRINT THE INFORMATION STORED IN THE HEADER BLOCK OF THE
C	FILE TN0700.EXT
C
C	HEADER ORDER 
C	REFFOM  REFMIS  HITMIN  RFAC  INRKNT  INPKNT  EMPKNT  RMPKNT
C	FOMKNT  PDFCNT  RSNUM  SCODES  ECODES  EIMAP(6)  NACMFL  
C	CHEMAP(6)  EXEMAP(6)
C	RSPACES BEGIN AT WORD 51
C
C	IBUF		BUFFER TO STORE HEADER
C	ITABLE		ELEMENTS TABLE
C	IBFOM		RECORD CONTAINING HEADER
C	RFAC		RETURNED AS CAMERA CONSTANT
C
C	CALLED BY:	CHEM
C	CALLS:		CHEEL,CHEFLG
C
	IMPLICIT BYTE (B), LOGICAL*1 (L), INTEGER*2 (I-K,M,N)
	DIMENSION IBUF(256),ITABLE(96)
	DATA IM1/"177777/
	READ (3'IBFOM) IBUF			!READ HEAD BLOCK
	RFAC = IBUF(4)/1000.			!CAMERA CONSTANT
	WRITE (6,10) (IBUF(I),I=1,3),RFAC
10	FORMAT (//' FOM CUTOFF VALUE (%):       ',I7,
     *		/ ' # OF RSPACE MISSES ALLOWED: ',I7,
     *		/ ' # OF ELEMENT HITS REQUIRED: ',I7,
     *		/ ' CAMERA CONSTANT (ANG-CM):   ',F7.3)
	WRITE (6,20) (IBUF(I),I=5,10)
20	FORMAT (//I6,' INDEX RECORDS WERE EXAMINED '
     *		 /I6,' RESULTED IN A CLOSER STUDY'
     *		 /I6,' ELEMENT MAPS CHECKED'
     *		 /I6,' R-SPACE MAPS CHECKED'
     *		 /I6,' FOM CALCULATIONS'
     *		 /I6,' # COMPOUNDS FOUND')
	WRITE (6,70)
70	FORMAT (//' DETECTED ELEMENTS '/1X)
	CALL CHEEL (ITABLE,IBUF(21))		!PRINT SYMBOLS
	WRITE (6,75)
75	FORMAT (/1X/' REQUIRED ELEMENTS '/1X)
	DO 76 I=14,19
76	IBUF(I) = IBUF(I) .XOR. IM1
	CALL CHEEL (ITABLE,IBUF(14))		!PRINT SYMBOLS
	WRITE (6,80)
80	FORMAT (/1X/' EXCLUDED ELEMENTS '/1X)
	CALL CHEEL (ITABLE,IBUF(27))		!PRINT SYMBOLS
	WRITE (6,90)
90	FORMAT (/1X/' FLAGS REQUIRED:  '$)
	CALL CHEFLG (IBUF(12))			!PRINT FLAGS
	WRITE (6,100)
100	FORMAT (1X/' FLAGS EXCLUDED:  '$)
	CALL CHEFLG (IBUF(13))			!PRINT FLAGS
	IF (IBUF(20).EQ.0) WRITE (6,110)
110	FORMAT (/' COMPOUNDS INCLUDING ONLY ELEMENTS ',
     *		'OUTSIDE THE RANGE NA-CM WERE NOT EXAMINED')
	IF (IBUF(20).EQ.1) WRITE (6,120)
120	FORMAT (/' COMPOUNDS INCLUDING ONLY ELEMENTS ',
     *		'OUTSIDE THE RANGE NA-CM WERE EXAMINED')
	WRITE (6,140) IBUF(11)
140	FORMAT (/1X/' ',I5,' R-SPACES ENTERED ')
	IF (IBUF(11).GT.0) WRITE (6,150) (IBUF(I)/1000.,I=51,50+IBUF(11))
150	FORMAT (1X,10F6.3)
	RETURN
	END
